==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/NumberFormatSpecifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSpecifierDescriptionMetadata } from "./FormatSpecifierDescriptionMetadata";
import { NumberFormatSpecifierDescription } from "./NumberFormatSpecifierDescription";
/**
 * @hidden
 */
export let NumberFormatSpecifierDescriptionMetadata = /*@__PURE__*/ (() => {
    class NumberFormatSpecifierDescriptionMetadata extends Base {
        static b(a) {
            if (NumberFormatSpecifierDescriptionMetadata.a == null) {
                NumberFormatSpecifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NumberFormatSpecifierDescriptionMetadata.c(NumberFormatSpecifierDescriptionMetadata.a);
            }
            if (a.j(NumberFormatSpecifierDescriptionMetadata.a)) {
                return;
            }
            a.y(NumberFormatSpecifierDescriptionMetadata.a);
        }
        static c(a) {
            FormatSpecifierDescriptionMetadata.c(a);
            a.item("Locale", "String");
            a.item("CompactDisplay", "String");
            a.item("Currency", "String");
            a.item("CurrencyDisplay", "String");
            a.item("CurrencySign", "String");
            a.item("CurrencyCode", "String");
            a.item("LocaleMatcher", "String");
            a.item("Notation", "String");
            a.item("NumberingSystem", "String");
            a.item("SignDisplay", "String");
            a.item("Style", "String");
            a.item("Unit", "String");
            a.item("UnitDisplay", "String");
            a.item("UseGrouping", "Boolean");
            a.item("MinimumIntegerDigits", "Number:int");
            a.item("MinimumFractionDigits", "Number:int");
            a.item("MaximumFractionDigits", "Number:int");
            a.item("MinimumSignificantDigits", "Number:int");
            a.item("MaximumSignificantDigits", "Number:int");
        }
        static d(a) {
            NumberFormatSpecifierDescriptionMetadata.b(a);
            a.aa("NumberFormatSpecifier", () => new NumberFormatSpecifierDescription());
            a.z("NumberFormatSpecifier", NumberFormatSpecifierDescriptionMetadata.a);
        }
    }
    NumberFormatSpecifierDescriptionMetadata.$t = /*@__PURE__*/ markType(NumberFormatSpecifierDescriptionMetadata, 'NumberFormatSpecifierDescriptionMetadata');
    NumberFormatSpecifierDescriptionMetadata.a = null;
    return NumberFormatSpecifierDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/NumberFormatSpecifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSpecifierDescriptionMetadata } from "./FormatSpecifierDescriptionMetadata";
import { NumberFormatSpecifierDescription } from "./NumberFormatSpecifierDescription";
/**
 * @hidden
 */
export let NumberFormatSpecifierDescriptionMetadata = /*@__PURE__*/ (() => {
    class NumberFormatSpecifierDescriptionMetadata extends Base {
        static b(a) {
            if (NumberFormatSpecifierDescriptionMetadata.a == null) {
                NumberFormatSpecifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NumberFormatSpecifierDescriptionMetadata.c(NumberFormatSpecifierDescriptionMetadata.a);
            }
            if (a.k(NumberFormatSpecifierDescriptionMetadata.a)) {
                return;
            }
            a.aa(NumberFormatSpecifierDescriptionMetadata.a);
        }
        static c(a) {
            FormatSpecifierDescriptionMetadata.c(a);
            a.item("Locale", "String");
            a.item("CompactDisplay", "String");
            a.item("Currency", "String");
            a.item("CurrencyDisplay", "String");
            a.item("CurrencySign", "String");
            a.item("CurrencyCode", "String");
            a.item("LocaleMatcher", "String");
            a.item("Notation", "String");
            a.item("NumberingSystem", "String");
            a.item("SignDisplay", "String");
            a.item("Style", "String");
            a.item("Unit", "String");
            a.item("UnitDisplay", "String");
            a.item("UseGrouping", "Boolean");
            a.item("MinimumIntegerDigits", "Number:int");
            a.item("MinimumFractionDigits", "Number:int");
            a.item("MaximumFractionDigits", "Number:int");
            a.item("MinimumSignificantDigits", "Number:int");
            a.item("MaximumSignificantDigits", "Number:int");
        }
        static d(a) {
            NumberFormatSpecifierDescriptionMetadata.b(a);
            a.ac("NumberFormatSpecifier", () => new NumberFormatSpecifierDescription());
            a.ab("NumberFormatSpecifier", NumberFormatSpecifierDescriptionMetadata.a);
        }
    }
    NumberFormatSpecifierDescriptionMetadata.$t = /*@__PURE__*/ markType(NumberFormatSpecifierDescriptionMetadata, 'NumberFormatSpecifierDescriptionMetadata');
    NumberFormatSpecifierDescriptionMetadata.a = null;
    return NumberFormatSpecifierDescriptionMetadata;
})();
